// #pragma comment(linker, "/stack:200000000")
// #pragma GCC optimize("Ofast,no-stack-protector")
// #pragma GCC target("sse,sse2,sse3,ssse3,sse4,popcnt,abm,mmx,avx,avx2,tune=native")
// #pragma GCC optimize("unroll-loops")

#include <stdio.h>
#include <bits/stdc++.h>

#ifdef PERVEEVM_LOCAL
    #define debug(x...) std::cerr << "[DEBUG]\t" << __LINE__ << ":\t" << (#x) << " = "; print_debug(x)
#else
    #define debug(x...) 238
#endif

#define fastIO std::ios_base::sync_with_stdio(false); std::cin.tie(0); std::cout.tie(nullptr)
#define NAME "File"

using ll = long long;
using ld = long double;

#ifdef PERVEEVM_LOCAL
    std::mt19937 rnd(238);
#else
    std::mt19937 rnd(std::chrono::high_resolution_clock::now().time_since_epoch().count());
#endif

template<typename T1, typename T2>
std::ostream& operator<<(std::ostream& out, const std::pair<T1, T2>& p) {
    out << "(" << p.first << ", " << p.second << ")";
    return out;
}

template<size_t index, typename T>
std::ostream& print_tuple(std::ostream& out, const T& t) {
    if constexpr (index == std::tuple_size<T>::value) {
        out << ")";
        return out;
    } else {
        if (index > 0) {
            out << ", ";
        } else {
            out << "(";
        }
        out << std::get<index>(t);
        return print_tuple<index + 1, T>(out, t);
    }
}

template<typename ...T>
std::ostream& operator<<(std::ostream& out, const std::tuple<T...>& t) {
    return print_tuple<0, std::tuple<T...>>(out, t);
}

template<typename Container, typename = decltype(std::begin(std::declval<Container>()))>
typename std::enable_if<!std::is_same<Container, std::string>::value, std::ostream&>::type
operator<<(std::ostream& out, const Container& container) {
    out << "{";
    for (auto it = container.begin(); it != container.end(); ++it) {
        if (it != container.begin()) {
            out << ", ";
        }
        out << *it;
    }
    out << "}";
    return out;
}

void print_debug() {
    std::cerr << std::endl;
}

template<typename T, typename... V>
void print_debug(const T& value, const V&... others) {
    std::cerr << value;
    if (sizeof...(others) != 0) {
        std::cerr << ", ";
        print_debug(others...);
    } else {
        std::cerr << std::endl;
    }
}

template<typename T>
bool smin(T& a, const T& b) {
    if (b < a) {
        a = b;
        return true;
    }
    return false;
}

template<typename T>
bool smax(T& a, const T& b) {
    if (a < b) {
        a = b;
        return true;
    }
    return false;
}

const double PI = atan2(0.0, -1.0);
const int INF = 0x3f3f3f3f;
const ll LINF = (ll)2e18;
const int N = 100100;

std::mt19937_64 rnd64(238);

struct treap {
    treap* l = nullptr;
    treap* r = nullptr;
    int x;
    int sz;
    ll y;

    treap(int _x) : x(_x), sz(1), y(rnd64()) {}
};

int n;
int p[N], rp[N];
std::pair<int, int> queries[N];
treap* roots[N];

int sz(treap* t) {
    if (t == nullptr) {
        return 0;
    } else {
        return t->sz;
    }
}

void update(treap* t) {
    t->sz = 1 + sz(t->l) + sz(t->r);
}

treap* newNode(treap* l, treap* r, int x) {
    treap* t = new treap(x);
    t->l = l;
    t->r = r;
    update(t);
    return t;    
}

treap* merge(treap* l, treap* r) {
    if (l == nullptr) {
        return r;
    }
    if (r == nullptr) {
        return l;
    }

    if ((ll)(rnd64() % (sz(l) + sz(r) + 1)) < sz(l)) {
        return newNode(l->l, merge(l->r, r), l->x);
    } else {
        return newNode(merge(l, r->l), r->r, r->x);
    }
}

// < x, >= x
std::pair<treap*, treap*> split(treap* t, int key) {
    if (t == nullptr) {
        return std::make_pair(nullptr, nullptr);
    }

    if (t->x >= key) {
        auto res = split(t->l, key);
        return std::make_pair(res.first, newNode(res.second, t->r, t->x));
    } else {
        auto res = split(t->r, key);
        return std::make_pair(newNode(t->l, res.first, t->x), res.second);
    }
}

treap* insert(treap* t, int x) {
    auto[l, r] = split(t, x);
    return merge(merge(l, new treap(x)), r);
}

int findKth(treap* t, int k) {
    if (k < sz(t->l)) {
        return findKth(t->l, k);
    } else if (k == sz(t->l)) {
        return t->x;
    } else {
        return findKth(t->r, k - sz(t->l) - 1);
    }
}

int findKth(int pref, int k) {
    treap* root = roots[pref];
    return rp[findKth(root, k)];
}

void run() {
    int q, k;
    scanf("%d%d%d", &n, &q, &k);

    for (int i = 0; i < n; ++i) {
        scanf("%d", &p[i]);
        --p[i];
        rp[p[i]] = i;
    }

    roots[0] = nullptr;
    for (int i = 0; i < n; ++i) {
        roots[i + 1] = insert(roots[i], p[i]);
    }

    for (int i = 0; i < q; ++i) {
        scanf("%d%d", &queries[i].first, &queries[i].second);
        --queries[i].first;
        --queries[i].second;
    }

    --k;
    for (int i = q - 1; i >= 0; --i) {
        auto[l, r] = queries[i];
        if (k < l || k > r) {
            continue;
        }

        int len = r - l + 1;
        int pos = findKth(len, k - l);
        k = l + pos;
    }

    printf("%d\n", k + 1);
}

int main(void) {
    // freopen(NAME".in", "r", stdin);
    // freopen(NAME".out", "w", stdout);

    #ifdef PERVEEVM_LOCAL
        auto start = std::chrono::high_resolution_clock::now();
    #endif

    run();

    #ifdef PERVEEVM_LOCAL
        auto end = std::chrono::high_resolution_clock::now();
        std::cerr << "Execution time: "
                  << std::chrono::duration_cast<std::chrono::milliseconds>(end - start).count()
                  << " ms" << std::endl;
    #endif

    return 0;
}
